@@ -222,6 +222,85 @@ def generate_mutation(
     return tree
 
 
+def generate_subscription(
+    o: OperationDefinitionNode,
+    client_schema: GraphQLSchema,
+    config: GeneratorConfig,
+    plugin_config: OperationsPluginConfig,
+):
+
+    tree = []
+
+    x = get_operation_root_type(client_schema, o)
+    query_fields = []
+    name = f"{config.prepend_subscription}{o.name.value.capitalize()}{config.append_subscription}"
+
+    for field_node in o.selection_set.selections:
+
+        field_node: FieldNode = field_node
+        field_definition = get_field_def(client_schema, x, field_node)
+        assert field_definition, "Couldn't find field definition"
+
+        target = (
+            field_node.alias.value
+            if hasattr(field_node, "alias") and field_node.alias
+            else field_node.name.value
+        )
+
+        query_fields += [
+            ast.AnnAssign(
+                target=ast.Name(target, ctx=ast.Store()),
+                annotation=recurse_annotation(
+                    field_node,
+                    field_definition.type,
+                    client_schema,
+                    config,
+                    tree,
+                    parent_name=name,
+                ),
+                simple=1,
+            )
+        ]
+
+    query_document = language.print_ast(o)
+    z = fragment_searcher.findall(query_document)
+
+    merged_document = replace_iteratively(query_document)
+
+    query_fields += [
+        ast.ClassDef(
+            "Meta",
+            bases=[],
+            decorator_list=[],
+            keywords=[],
+            body=[
+                ast.Assign(
+                    targets=[ast.Name(id="domain", ctx=ast.Store())],
+                    value=ast.Constant(value=str(config.domain)),
+                ),
+                ast.Assign(
+                    targets=[ast.Name(id="document", ctx=ast.Store())],
+                    value=ast.Constant(value=merged_document),
+                ),
+            ],
+        )
+    ]
+    tree.append(
+        ast.ClassDef(
+            name,
+            bases=[
+                ast.Name(id=base.split(".")[-1], ctx=ast.Load())
+                for base in plugin_config.mutation_bases
+            ],
+            decorator_list=[],
+            keywords=[],
+            body=query_fields,
+        )
+    )
+
+    return tree
+
+
 class OperationsPlugin(Plugin):
     def __init__(self, config=None, **data):
         self.plugin_config = config or OperationsPluginConfig(**data)
@@ -276,5 +355,9 @@ class OperationsPlugin(Plugin):
                 plugin_tree += generate_mutation(
                     operation, client_schema, config, self.plugin_config
                 )
+            if operation.operation == OperationType.SUBSCRIPTION:
+                plugin_tree += generate_subscription(
+                    operation, client_schema, config, self.plugin_config
+                )
 
         return plugin_tree
